@@ -1,5 +1,5 @@
 #!/usr/bin/env seed
-Seed.import_namespace("GLib");
+GLib = imports.gi.GLib;
 
 count = 0;
 one = true;
