@@ -5,11 +5,10 @@ Notify = imports.gi.Notify;
 
 Gtk.init(null, null);
 
-function file_changed(monitor, child, other, event)
-{
+function file_changed(monitor, child, other, event){
     var notification =
 	new Notify.Notification({summary: "File Notification",
-                             body : "It's not clear what notification system this file is providing an example of." });
+				 body : "It's not clear what notification system this file is providing an example of." });
     notification.set_timeout(5000);
     notification.show();
 }
@@ -24,3 +23,4 @@ monitor.signal.changed.connect(file_changed);
 
 Gtk.main();
 
+
