@@ -7,21 +7,11 @@
 Gtk = imports.gi.Gtk;
 Gtk.init(null, null);
 
-HelloWindowType = {       
+HelloWindowType = {
     parent: Gtk.Window.type,
     name: "HelloWindow",
-    class_init: function(klass, prototype)
-    {
-	var HelloSignalDefinition = {name: "hello"};
-	var GoodbyeSignalDefinition = {name: "goodbye"};
-	
-	
-	hello_signal_id = klass.install_signal(HelloSignalDefinition);
-	goodbye_signal_id = klass.install_signal(GoodbyeSignalDefinition);
-    },
-    init: function(instance)
-    {
-    }};
+    signals: [{name: "hello"}, {name: "goodbye"}]
+};
 
 HelloWindow = new GType(HelloWindowType);
 w = new HelloWindow();
@@ -31,4 +21,4 @@ w.signal.goodbye.connect(function(){Seed.print("Goodbye");});
 
 w.signal.hello.emit();
 w.signal.goodbye.emit();
-	  
+
